#!/bin/bash
#

# build_swig.sh <product_directory> <e10|e14|e15|e17|c2> <debug|prof> [tar] [source]

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <e10|e14|e15|e17|c2> <debug|prof> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
extraqual=${3}
maketar=${4}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=swig
origpkgver=v3_0_12
pkgver=${origpkgver}d
ssibuildshims_version=v1_04_13
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=swig-${pkgdotver}

get_this_dir

get_ssibuildshims

source define_basics --

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   exit 0
fi

echo "building ${package} for ${OS}-${plat}-${qualdir} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# setup so we get the expected compiler
setup -B ${package} ${pkgver} -q ${fullqual} -z ${fakedb}:${PRODUCTS}

# Common configure args

common_config_args="--prefix=${pkgdir}
 --enable-cpp11-testing"

# Debug configure args
debug_config_args="--disable-silent-rules"

# Profile configure args
prof_config_args=""

if [ "${extraqual}" = "debug" ]
then
    extra_config_args="${debug_config_args}"
elif [ "${extraqual}" = "prof" ]
then
    extra_config_args="${prof_config_args}"
fi


mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi
mkdir -p ${sourcedir}
if [ ! -d ${sourcedir} ]
then
   echo "ERROR: failed to create ${sourcedir}"
   exit 1
fi

ncore=`${SSIBUILDSHIMS_DIR}/bin/ncores`
extra_command="-j ${ncore}"

if [[ "${basequal}" == e1[045] ]]; then
  compiler=gcc
  export CC=gcc
  export CXX=g++
  extra_command="stdver=c++14 ${extra_command}"
elif [[ "${basequal}" == e1[79] ]]; then
  compiler=gcc
  export CC=gcc
  export CXX=g++
  extra_command="stdver=c++17 ${extra_command}"
elif [[ "${basequal}" == c[27] ]]; then
  compiler=clang
  export CC=clang
  export CXX=clang++
  extra_command="stdver=c++17 ${extra_command}"
#elif [[ "${basequal}" == "i1" ]]; then
#  compiler=icc
#  extra_command="stdver=c++11 ${extra_command}"
else
  ssi_die "ERROR: unrecognized qualifier $basequal."
fi

set -x 

cd "${sourcedir}"
tar xf ${tardir}/${pkgtarname}.tar.gz || die "Unable to untar source."

cd ${blddir}
# Configure
${sourcedir}/${pkgtarname}/configure ${common_config_args} ${extra_config_args} || die "ERROR: configure failed."

make compiler=${compiler} ${extra_command} || die "ERROR: make failed."

make install || die "ERROR: make install failed."

set +x

# Clean up.
cd "${pkgdir}"

# # Wrapper scripts and config files.
# find bin etc -type f | while read file; do
#  [[ "$(file "${file}")" == *"text"* ]] && \
#   perl -wapi\~ -e 's&\Q'"${pkgdir}"'\E&\${SWIG_FQ_DIR}&g' "${file}"
#done

# libtool and pkg-config files not useful. Also backups.
#rm -rvf lib/pkgconfig lib/*.la
find . -name '*~' -exec rm -vf \{\} \;
rm -rf ${sourcedir}

${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}:${PRODUCTS}
echo "swig is installed at ${SWIG_FQ_DIR}"

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/share ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
